@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2008-2016 Sergey Poznyakoff
+   Copyright (C) 2008-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@ dicod_xlevdist(dico_stream_t str, int argc, char **argv)
 }
 	
 void
-register_lev()
+register_lev(void)
 {
     int i;
     static struct dicod_command cmd[] = {
