@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2008-2016 Sergey Poznyakoff
+   Copyright (C) 2008-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ struct dico_key {
     int flags;
 };
 
-int dico_strat_name_cmp(const void *item, void *data);
+int dico_strat_name_cmp(const void *item, const void *data, void *closure);
 int dico_strat_free(void *item, void *data);
 
 dico_strategy_t dico_strategy_create(const char *name, const char *descr);
