@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico
-   Copyright (C) 2008, 2010, 2012 Sergey Poznyakoff
+   Copyright (C) 2008-2018 Sergey Poznyakoff
   
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ make_full_file_name(const char *dir, const char *file)
 }
 
 dico_list_t
-xdico_list_create()
+xdico_list_create(void)
 {
     dico_list_t p = dico_list_create();
     if (!p)
